package com.awesome.screen_controller;

import android.annotation.SuppressLint;

import io.flutter.Log;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * ScreenPlugin
 */
public class ScreenControllerPlugin implements MethodCallHandler, ScreenListener {


    @SuppressLint("StaticFieldLeak")
    private static ScreenBroadcastReceiver sScreenReceiver;
    private static ScreenControllerPlugin sScreenPlugin;

    private EventChannel.EventSink sScreenSink;


    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {

        if (sScreenPlugin == null) {
            sScreenPlugin = new ScreenControllerPlugin();
        }
        final MethodChannel channel = new MethodChannel(registrar.messenger(),
                "com.awesome.screen_plugin");
        channel.setMethodCallHandler(sScreenPlugin);

        if (sScreenReceiver == null) {
            sScreenReceiver = new ScreenBroadcastReceiver(registrar.context(), sScreenPlugin);
        }

        EventChannel status_channel = new EventChannel(registrar.messenger(), "com.awesome.listener");
        status_channel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object o, EventChannel.EventSink eventSink) {
                sScreenPlugin.setListener(eventSink);
            }

            @Override
            public void onCancel(Object o) {

            }
        });

    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case "com.awesome.isScreenOn":
                if (sScreenReceiver != null) {
                    result.success(sScreenReceiver.getScreenState());
                }
                break;
            case "com.awesome.register":
                Log.d("111", "===============绑定=========");
                if (sScreenReceiver != null) {
                    sScreenReceiver.registerScreenBroadcastReceiver();
                }
                break;
            case "com.awesome.unregister":
                Log.d("111", "===============解绑=========");
                if (sScreenReceiver != null) {
                    sScreenReceiver.unRegisterScreenBroadcastReceiver();
                }
                break;
        }

    }


    @Override
    public void onScreenStateChange(boolean isOpen) {
        if (sScreenSink != null) {
            sScreenSink.success(isOpen);
        }
    }


    private void setListener(EventChannel.EventSink sink) {
        this.sScreenSink = sink;
    }
}
